#

#
# Software subject to following license(s):
#   Apache 2 License (http://www.opensource.org/licenses/apache2.0)
#   Copyright (c) Responsible Organization
#

#
# Current developer(s):
#   Kenneth Waegeman <Kenneth.Waegeman@UGent.be>
#



package NCM::Component::Ceph::Cfgfile;

use strict;
use warnings;

use version;
our $VERSION = version->new("v23.9.0");



use parent qw(CAF::Object);
use Readonly;
use EDG::WP4::CCM::TextRender;
Readonly my $CEPH_CFGFILE => '/etc/ceph/ceph.conf';

sub _initialize
{
    my ($self, $config, $log, $path, $cfgfile, $owner) = @_;

    $self->{log} = $log;
    $self->{path} = $path;
    $self->{tree} = $config->getTree($self->{path}, undef, convert_list =>
        [$EDG::WP4::CCM::TextRender::ELEMENT_CONVERT{arrayref_join_comma}]);

    $self->{cfgfile} = $cfgfile || $CEPH_CFGFILE;
    $self->{owner} = $owner || 'root';
    return 1;
}

sub write_cfgfile
{
    my ($self) = @_;

    my $rgw = delete $self->{tree}->{rgw} || {};
    my $newtree = {%{$self->{tree}}, %$rgw};

    my $trd = EDG::WP4::CCM::TextRender->new('tiny', $newtree, log => $self);
    my $fh = $trd->filewriter($self->{cfgfile}, owner => $self->{owner});
    if (!$fh) {
        $self->error("Could not write ceph config file $self->{cfgfile}: $trd->{fail}");
        return;
    };
    $fh->close();
    $self->debug(1, "done processing config file $self->{cfgfile}");
    return 1;

}

sub configure
{
    my ($self) = @_;

    return if (!$self->write_cfgfile());

    return 1;
}

1;
